<?php

/**
 * This file contains \QUI\FormBuilder\Interfaces\Field
 */

namespace QUI\FormBuilder\Interfaces;

use QUI;
use QUI\FormBuilder\Builder;

/**
 * Interface Field
 * @package QUI\FormBuilder\Interfaces
 */
interface Field
{
    /**
     * Field constructor.
     * @param Builder $Form
     */
    public function __construct(QUI\FormBuilder\Builder $Form);

    /**
     * Return the Body of the Field
     * @return string
     */
    public function getBody(): string;

    /**
     * Return the html of the element for the mail body
     * @return string
     */
    public function getHtmlForMail(): string;

    /**
     * Check tha value data of the field
     * @throws QUI\Exception
     */
    public function checkValue(): void;

    /**
     * Get text for the current value of the form field
     *
     * @return string
     */
    public function getValueText(): string;

    /**
     * Parse form data and put it in the right format for evaluation / display
     *
     * @param array $data
     * @return mixed
     */
    public function parseFormData(array $data): mixed;

    /**
     * Set the field parent
     *
     * @param Builder $Form
     */
    public function setParent(Builder $Form): void;

    /**
     * Return the field parent
     *
     * @return null|Builder
     */
    public function getParent(): ?Builder;

    /**
     * Set internal name id
     *
     * @param int $id
     */
    public function setNameId(int $id): void;

    /**
     * Get name
     *
     * @return string
     */
    public function getName(): string;

    public function getAttribute(string $k): mixed;

    public function setAttribute(string $k, mixed $v): void;

    public function getAttributes(): array;
}
